---------------------------------------------------------------
-- One small problem when being portable is that Windows has an 
-- an annoying habit of putting <cr>\n at the end of each line. 
-- unfortunately this means that when readin the file in Unix it
-- makes no real sense. 
--
-- This example gets around the problem by checking the last
-- char of all lines in a file. If the last value is 13 then 
-- we have a Win32 file and the char is stripped.
--
-- All lines are then built up in a table that this function 
-- returns. If you want to see an example of how to use this
-- script then see the winamp example which uses it to read an
-- m3u file.
---------------------------------------------------------------

function ReadTextFile( filename )

	-- the table we will fill with strings
	--
	local ReturnStuff = {};
	
	-- read each line in the file
	--
	for line in io.lines(filename) do
	
		-- use the string.byte function to query the ascii
		-- value of the last char
		--
		local lastchar = string.byte(line,-1);
		
		-- if the value is 13 then we have a carriage return
		--
		if lastchar == 13 then
		
			-- insert the stripped string at the end of the table
			--
			table.insert( ReturnStuff, string.sub(line,1,-2) );
			
		else
			
			-- insert the string at the end of the table
			--
			table.insert( ReturnStuff, line );
			
		end
	end
	
	-- return the table
	--
	return ReturnStuff;
	
end

---------------------------------------------------------------
-- print something out just incase people think that this script
-- doesn't actually do anything ;)
---------------------------------------------------------------

print("This example may not seem to actually do very much.");
print("Try running something like this on a text file:\n");
print("Lines = ReadTextFile(\"SomeFile.txt\");\n");
print("Lines will now be a table variable containing all lines");
print("from the file. To use the table you can then do something");
print("like:\n");
print("for line in Lines do\n\tprint(line);\nend\n");
print("It's probably a good idea to take a wee look at the script!");

